@@ -230,19 +230,25 @@ class TaskJugglerScheduler(SchedulerBase):
         # pass it to tj3
         proc = subprocess.Popen(
             [defaults.tj_command,
-             self.tjp_file_full_path],
+            self.tjp_file_full_path],
             stderr=subprocess.PIPE
         )
         # wait it to complete
         proc.wait()
 
+        stderr = proc.stderr.readlines()
+
         if proc.returncode:
-            raise RuntimeError(proc.stderr.readlines())
+            # there is an error
+            raise RuntimeError(stderr)
 
-        logger.debug('tj3 return code: %s' % proc.returncode)
-        logger.debug('tj3 output: %s' % proc.stderr.readlines())
         # read back the csv file
         self._parse_csv_file()
 
+        logger.debug('tj3 return code: %s' % proc.returncode)
+        logger.debug('tj3 output: %s' % stderr)
+
         # remove the tjp file
         #self._clean_up()
+
+        return stderr
